func fitlsqn(y,x,xp,n)
/* DOCUMENT fitlsqn(y,x,xp,n)
   Fits an n-degree polynomial to the points y as a function of x. The
   returned values are given for the values in xp, as in interp.
   The value of n should be <= numberof(x)
*/
{
C=array(double,n+1,numberof(x));
yp=array(double,numberof(xp));
p=span(0,n,n+1);
if (n<1 || n>(numberof(x)-1)) exit;
C(1,)=1;
for (i=0s;i<=n;i++)
 C(i+1,)=x^i;
v=C(,+)*y(+);
P=C(,+)*C(,+);
xtemp=QRsolve(P,v);
for (i=0;i<=n;i++)
yp=yp+xtemp(i+1)*xp^i;
return yp;
} 

func fitnonpar(y,x,xp,h)
/* DOCUMENT fitnonpar(y,x,xp,h)
   Fits a non-parametric set of points through matrices y=f(x), with
   smoothness parameter h, which should be of the order of the distance
   between consecutive x-points.
*/
{ n=numberof(xp);
  yp=array(double,n);
  for(i=1s;i<=n;i++)
   {
    yp(i)=sum(y*exp(-0.5* ((x-xp(i))/h)^2 ))/sum(exp(-0.5* ((x-xp(i))/h)^2 ));
   }
return yp;
}
