/* MAKE-INSTRUCTIONS
SRCS = read.c
*/

func flags(desc)
/*DOCUMENT sets up frame flags in an easy manner 
      'a':  left or lower axis tick marks 
      'b':  right or upper tick marks
      'c':  center tick marks 
      'G':  full grid lines 
      'g':  grid line through origin 
      'i':  inward ticks 
      'l':  ticks on lower or left edge 
      'u':  ticks on upper or right edge 
      'A':  Use alternate tick algorithm 
      'M':  third parameter in plwind indicates 1st major tick 
      'E':  Format 4.35E2 
      'P':  Format 7.3410^45 
*/   
{ return y_flags(desc);
}
extern y_flags;
/* PROTOTYPE 
 int flags(string desc)
*/

func plstick(Paper,xnum,ynum,currentx,currenty,top,right,bot,left)
{local x,y;
 x=array(double,4);
 y_sticky_window,xnum,ynum,currentx,currenty,top,right,bot,left,x;
 return [x(1)*Paper.xmax+Paper.xmin, x(2)*Paper.xmax+Paper.xmin, 
      x(3)*Paper.ymax+Paper.ymin, x(4)*Paper.ymax+Paper.ymin];
}
extern y_sticky_window;
/* PROTOTYPE
void sticky_window(double xnum,double ynum,double currentx,double currenty,double top,double
right,double bot,double left,double array x)
*/

func plwind(xnum,ynum,currentx,currenty)
{return plstick(xnum,ynum,currentx,currenty,10,10,20,20);
}
func pwrite_data(fname,x,y)
/* DOCUMENT pwrite_data(fname,x,y)
  Prints out the arrays of double "x" and "y" to file "fname" in two column 
  format
*/
{ return y_pwrite_data(fname,x,y,numberof(x));
}
extern y_pwrite_data;
/* PROTOTYPE
   int write_data(string fname, double array x, double array y, int n)
*/

func pread_column(fname,line1,line2,xcol)
/* DOCUMENT pread_column(fname, line1, line2, xcol)
  Reads an vector of doubles from file "fname", from column no. "xcol",
  starting at "line1" and ending at "line2". Missing values should be marked
  with a '*'. The result of the function is a vector.
*/
{ local num,xsize,x,y; 
 xsize=(line2-line1+1);
 x=array(double,xsize)
 num=y_pread_column(fname,line1,line2,xcol,x,xsize);
 if (num<xsize)
 { write, "pread_column warning: less values found than expected, check file.", num;
   if (num>=1) y=x(1:num);
   else y=[];
   return y;
 }
 else return x;
}
extern y_pread_column;
/* PROTOTYPE
   int read_data(string fname, int line1, int line2, int xcol, double array x, int n)
*/

func pread_matrix(fname,line1,line2,xcol,xnum)
/* DOCUMENT pread_matrix(fname, line1, line2, xcol,xnum)
  Reads an array of doubles from file "fname", xnum columns starting 
  from column no. "xcol", starting at "line1" and ending at "line2". 
  Missing values should be marked with a '*'. The result of the function is
  an array of doubles.
*/
{ local num,xsize,x,y; 
 xsize=(line2-line1+1);
 x=array(double,xnum,xsize)
 num=y_pread_matrix(fname,line1,line2,xcol,x,xnum);
 if (num<xsize)
 { write, "pread_matrix warning: less values found than expected, check file.", num;
   if (num>=1) y=x(1:xnum,1:num);
   else y=[];
   return y;
 }
 else return x;
}
extern y_pread_matrix;
/* PROTOTYPE
  int my_read_matrix(string fname, int line1, int line2, int xcol, double array x, int n)
*/


func pread_block(fname,blocknum,blockstart,xcol,xsize)
/* DOCUMENT func pread_block(fname,blocnum,blockstart,xcol,xsize)
  Reads an array of doubles from file "fname", from block no. "blocknum".
  A block is defined as starting with the string in "blockstart". Values are
  read from the column "xcol". Missing values should be marked with "*".
  Because the length of the block is unknown, a maximum size "xsize" must be
  specified. The result of the function is a vector.
*/
{ local num,y,x; 
 x=array(double,xsize);
 num=y_pread_block(fname,blocknum,blockstart,xcol,x,xsize);
 if (num<xsize)
 { if (num>=1) y=x(1:num);
   else y=[];
   return y;
 }
 else return x;
}
extern y_pread_block;
/* PROTOTYPE
int read_block(string fname, int bnum, string bstart, int xcol, double array x, int xsize)
*/

func pread_matblock(fname,blocknum,blockstart,xstart,xnum,xsize)
/* DOCUMENT func pread_matblock(fname,blocnum,blockstart,xcol,xnum,xsize)
  Reads an array of doubles from file "fname", from block no. "blocknum".
  A block is defined as starting with the string in "blockstart". Values are
  read from the column "xcol". Missing values should be marked with "*".
  Because the length of the block is unknown, a maximum size "xsize" must be
  specified. The result of the function is a vector.
*/
{ local y,x; 
  extern dims;
  reshape, dims,int,2;
 x=array(double,xnum,xsize);
 dims=[0,0];
 y_pread_matblock,fname,blocknum,blockstart,xstart,xnum,x,xsize;
 if (dims(2)<xsize || dims(1)<xnum)
 { if (dims(2)>=1) y=x(1:dims(1),1:dims(2));
   else y=[];
   return y;
 }
 else return x;
}
extern y_pread_matblock;
/* PROTOTYPE
void my_read_matblock(string fname, int bnum, string bstart, int xcol, int xnum,double array x,int xsize)
*/
func logxfilter(x,y)
/* DOCUMENT func logxfilter(x,y)
   Filters the the vectors "x" for values of "y" that are <=0. Returns the
   modified x vector, so must be called twice with the two unmodified
   vectors to filter out unwated values from both vectors for plotting.
*/
{ local n, n1,xtemp1,ytemp2,ytemp;
  n1=numberof(x);
  if (n1>0)
   { xtemp1=array(double,n1);
     ytemp=array(double,n1);
     n=y_logfilter(n1,x,y,xtemp1,ytemp);
     if (n>0)
       xtemp2=xtemp1(1:n);
     else
       xtemp2=[];
     return xtemp2;
    }
   else
    return [];
}

extern y_logfilter;
/* PROTOTYPE
int logfilter(int n, double array x,double array y, double array a,double array b)
*/

func logxyfilter(x,y)
/* DOCUMENT func logxyfilter(x,y)
   Filters the the vectors "x" for values of "x" and "y" that are <=0. Returns the
   modified x vector, so must be called twice with the two unmodified
   vectors to filter out unwated values from both vectors for plotting.
*/
{ local n, n1,xtemp1,ytemp2,ytemp;
  n1=numberof(x);
  if (n1>0)
   { xtemp1=array(double,n1);
     ytemp=array(double,n1);
     n=xy_logfilter(n1,x,y,xtemp1,ytemp);
     if (n>0)
       xtemp2=xtemp1(1:n);
     else
       xtemp2=[];
     return xtemp2;
    }
   else
    return [];
}

extern xy_logfilter;
/* PROTOTYPE
int logxyfilter(int n, double array x,double array y, double array a,double array b)
*/


